==> react-idle-timer-5.5.1.tgz: package/README.md <==
<p align="center">
  <a href="https://idletimer.dev">
    <img height="100" src="./logo.svg" />
  </a>
</p>
<h1 align="center">React Idle Timer</h1>

<p align="center">
  <a href="https://www.npmjs.com/package/react-idle-timer">
    <img src="https://img.shields.io/npm/v/react-idle-timer.svg?label=version&color=ff8127" alt="Version">
  </a>
  <a href="https://github.com/supremetechnopriest/react-idle-timer/blob/master/LICENSE">
    <img src="https://img.shields.io/npm/l/react-idle-timer?color=ff7531" alt="License">
  </a>
  <a href="https://www.npmjs.com/package/react-idle-timer">
    <img src="https://img.shields.io/npm/dt/react-idle-timer.svg?color=ff693b" alt="Downloads">
  </a>
  <a href="https://github.com/sponsors/supremetechnopriest?logo=github">
    <img src="https://img.shields.io/github/sponsors/supremetechnopriest?color=ff5c45" alt="GitHub Sponsors">
  </a>
  <a href="https://codeclimate.com/github/SupremeTechnopriest/react-idle-timer/test_coverage">
    <img src="https://img.shields.io/github/workflow/status/SupremeTechnopriest/react-idle-timer/tests?label=tests&color=ff4f50" alt="Tests">
  </a>
  <a href="https://codeclimate.com/github/SupremeTechnopriest/react-idle-timer/test_coverage">
    <img src="https://img.shields.io/codeclimate/coverage/SupremeTechnopriest/react-idle-timer?color=ff415b"alt="Test Coverage">
  </a>
  <a href="https://codeclimate.com/github/SupremeTechnopriest/react-idle-timer/maintainability">
    <img src="https://img.shields.io/codeclimate/maintainability/SupremeTechnopriest/react-idle-timer?color=ff3266" alt="Maintainability">
  </a>
  <a href="https://discord.gg/YPuxNdWA4D">
    <img src="https://img.shields.io/discord/942899080621862913?color=ff2371&label=discord" alt="Discord">
  </a>
</p>

</br>

Welcome to the all new IdleTimer! The documentation has moved to [https://idletimer.dev](https://idletimer.dev). There you can find everything you need to get started using and contributing to IdleTimer.

</br>
</br>

<p align="center">
  <a href="https://idletimer.dev">
    <img src="https://img.shields.io/badge/%20-docs-ff8127.svg?&longCache=true&style=for-the-badge" alt="Docs" />
  </a>
  <a href="https://discord.gg/YPuxNdWA4D">
    <img src="https://img.shields.io/badge/%20-discord-ff554b.svg?&longCache=true&style=for-the-badge" alt="Discord" />
  </a>
  <a href="https://github.com/supremetechnopriest/react-idle-timer/issues/new/choose">
    <img src="https://img.shields.io/badge/%20-issues-FF2371.svg?&longCache=true&style=for-the-badge" alt="Issues" />
  </a>
</p>

<p align="center">
  <a href="https://github.com/standard/standard">
    <img src="https://cdn.rawgit.com/standard/standard/master/badge.svg" alt="JavaScript Style Guide" />
  </a>
</p>

==> react-idle-timer-5.7.2.tgz: package/README.md <==
<p align="center">
  <a href="https://idletimer.dev">
    <img height="100" src="./logo.svg" />
  </a>
</p>
<h1 align="center">React Idle Timer</h1>

<p align="center">
  <a href="https://www.npmjs.com/package/react-idle-timer">
    <img src="https://img.shields.io/npm/v/react-idle-timer.svg?label=version&color=ff8127" alt="Version">
  </a>
  <a href="https://github.com/supremetechnopriest/react-idle-timer/blob/master/LICENSE">
    <img src="https://img.shields.io/npm/l/react-idle-timer?color=ff7531" alt="License">
  </a>
  <a href="https://www.npmjs.com/package/react-idle-timer">
    <img src="https://img.shields.io/npm/dt/react-idle-timer.svg?color=ff693b" alt="Downloads">
  </a>
  <a href="https://github.com/sponsors/supremetechnopriest?logo=github">
    <img src="https://img.shields.io/github/sponsors/supremetechnopriest?color=ff5c45" alt="GitHub Sponsors">
  </a>
  <a href="https://github.com/SupremeTechnopriest/react-idle-timer/actions/workflows/tests.yml">
    <img src="https://img.shields.io/github/actions/workflow/status/SupremeTechnopriest/react-idle-timer/tests.yml?branch=master&label=tests&color=ff4f50" alt="Tests">
  </a>
  <a href="https://codeclimate.com/github/SupremeTechnopriest/react-idle-timer/test_coverage">
    <img src="https://img.shields.io/codeclimate/coverage/SupremeTechnopriest/react-idle-timer?color=ff415b"alt="Test Coverage">
  </a>
  <a href="https://codeclimate.com/github/SupremeTechnopriest/react-idle-timer/maintainability">
    <img src="https://img.shields.io/codeclimate/maintainability/SupremeTechnopriest/react-idle-timer?color=ff3266" alt="Maintainability">
  </a>
  <a href="https://discord.gg/YPuxNdWA4D">
    <img src="https://img.shields.io/discord/942899080621862913?color=ff2371&label=discord" alt="Discord">
  </a>
</p>

</br>

Welcome to the all new IdleTimer! The documentation has moved to [https://idletimer.dev](https://idletimer.dev). There you can find everything you need to get started using and contributing to IdleTimer.

</br>
</br>

<p align="center">
  <a href="https://idletimer.dev">
    <img src="https://img.shields.io/badge/%20-docs-ff8127.svg?&longCache=true&style=for-the-badge" alt="Docs" />
  </a>
  <a href="https://discord.gg/YPuxNdWA4D">
    <img src="https://img.shields.io/badge/%20-discord-ff554b.svg?&longCache=true&style=for-the-badge" alt="Discord" />
  </a>
  <a href="https://github.com/supremetechnopriest/react-idle-timer/issues/new/choose">
    <img src="https://img.shields.io/badge/%20-issues-FF2371.svg?&longCache=true&style=for-the-badge" alt="Issues" />
  </a>
</p>

<p align="center">
  <a href="https://github.com/standard/standard">
    <img src="https://cdn.rawgit.com/standard/standard/master/badge.svg" alt="JavaScript Style Guide" />
  </a>
</p>
